@@ -53,10 +53,6 @@ import qualified Data.Foldable as F
 import Control.Monad
 
 import Data.ByteString.Builder.Internal
-
-#if !MIN_VERSION_base(4,8,0)
-import Data.Monoid (Monoid(..))
-#endif
 import Data.Semigroup (Semigroup(..))
 
 ------------------------------------------------------------------------------
