@@ -1,16 +1,11 @@
 {-# LANGUAGE CPP, OverloadedStrings #-}
-#if __GLASGOW_HASKELL__ >= 704
+
 {-# OPTIONS_GHC -fsimpl-tick-factor=40000 #-}
-#endif
+
 -- | Tests for the Blaze builder
 --
 module Main where
 
-#if !MIN_VERSION_base(4,8,0)
-import Control.Applicative ((<$>))
-import Data.Monoid (mempty, mappend, mconcat)
-#endif
-
 import qualified Data.Text as T
 import qualified Data.ByteString.Lazy as LB
 import Test.Framework
